//
// Created by lukas on 06.12.20.
//

#ifndef PUMPENSTEUERUNG_SETTINGSSERVICE_H
#define PUMPENSTEUERUNG_SETTINGSSERVICE_H

#include <HttpEndpoint.h>

#define SETTINGS_ENDPOINT_PATH "/rest/settings"

class SettingState {
public:
    int maxpumpduration;
    int waterOutageWaitDuration;
    int heatUp;
    int heatLow;
    int fanRuntime;

    SettingState() : maxpumpduration(600), waterOutageWaitDuration(3600), heatUp(65), heatLow(60), fanRuntime(60) {}

    static void read(SettingState &settings, JsonObject &root) {
        // read currently defined values
        Serial.println("read called");
        root["maxpumpduration"] = settings.maxpumpduration;
        root["waterOutageWaitDuration"] = settings.waterOutageWaitDuration;
        root["heatUp"] = settings.heatUp;
        root["heatLow"] = settings.heatLow;
        root["fanRuntime"] = settings.fanRuntime;
    }

    static StateUpdateResult update(JsonObject &root, SettingState &settings) {
        // store new values defined in ui
        Serial.println("update called");

        int newMaxPump = root["maxpumpduration"];
        int newWaterOutDur = root["waterOutageWaitDuration"];
        int newHeatUp = root["heatUp"];
        int newHeatLow = root["heatLow"];
        int newfanRuntime = root["fanRuntime"];

        bool change = false;

        if (newMaxPump != settings.maxpumpduration) {
            settings.maxpumpduration = newMaxPump;
            change = true;
        }

        if (newWaterOutDur != settings.waterOutageWaitDuration) {
            settings.waterOutageWaitDuration = newWaterOutDur;
            change = true;
        }

        if (newHeatUp != settings.heatUp) {
            settings.heatUp = newHeatUp;
            change = true;
        }

        if (newHeatLow != settings.heatLow) {
            settings.heatLow = newHeatLow;
            change = true;
        }

        if (newfanRuntime != settings.fanRuntime) {
            settings.fanRuntime = newfanRuntime;
            change = true;
        }

        return change ? StateUpdateResult::CHANGED : StateUpdateResult::UNCHANGED;
    }

    static void haRead(SettingState &settings, JsonObject &root) {
        Serial.println("haRead called");
//        root["state"] = settings.ledOn ? "ON" : "OFF";
    }

    static StateUpdateResult haUpdate(JsonObject &root, SettingState &lightState) {
        Serial.println("haupdate called");
        String state = root["state"];
//        // parse new led state
//        boolean newState = false;
//        if (state.equals("ON")) {
//            newState = true;
//        } else if (!state.equals("OFF")) {
//            return StateUpdateResult::ERROR;
//        }
//        // change the new state, if required
//        if (lightState.ledOn != newState) {
//            lightState.ledOn = newState;
//            return StateUpdateResult::CHANGED;
//        }
        return StateUpdateResult::UNCHANGED;
    }
};

class SettingsService : public StatefulService<SettingState> {
public:
    SettingsService(AsyncWebServer *server, SecurityManager *securityManager);

    void begin();

    const SettingState* getSettings();

private:
    HttpEndpoint<SettingState> _httpEndpoint;

    void onConfigUpdated();
};


#endif //PUMPENSTEUERUNG_SETTINGSSERVICE_H
